/*! vue-feather v2.0.0-alpha | (c) 2018-present Chen Fengyuan | MIT */
import { h } from 'vue';
import feather from 'feather-icons';

const VueFeather = (props, context) => {
    const { animation, animationSpeed, size, type, } = props;
    const icon = feather.icons[type];
    return h(props.tag, {
        ...context.attrs,
        'data-name': type,
        'data-tags': icon ? icon.tags : '',
        'data-type': type,
        class: {
            'vue-feather': true,
            [`vue-feather--${type}`]: type,
            [`vue-feather--${animation}`]: animation,
            [`vue-feather--${animationSpeed}`]: animationSpeed,
        },
    }, [
        icon ? h('svg', {
            ...icon.attrs,
            fill: props.fill,
            height: size,
            stroke: props.stroke,
            'stroke-linecap': props.strokeLinecap,
            'stroke-linejoin': props.strokeLinejoin,
            'stroke-width': props.strokeWidth,
            width: size,
            class: [icon.attrs.class, 'vue-feather__content'],
        }, [
            h({
                template: icon.contents,
            }),
        ]) : '',
    ]);
};
VueFeather.props = {
    animation: {
        type: String,
        default: undefined,
    },
    animationSpeed: {
        type: String,
        default: undefined,
    },
    fill: {
        type: String,
        default: 'none',
    },
    size: {
        type: [Number, String],
        default: 24,
    },
    stroke: {
        type: String,
        default: 'currentColor',
    },
    strokeLinecap: {
        type: String,
        default: 'round',
    },
    strokeLinejoin: {
        type: String,
        default: 'round',
    },
    strokeWidth: {
        type: [Number, String],
        default: 2,
    },
    tag: {
        type: String,
        default: 'i',
    },
    type: {
        type: String,
        required: true,
        validator(type) {
            if (!feather) {
                throw new Error('The Feather icons is required.');
            }
            if (!feather.icons[type]) {
                throw new Error(`"${type}" is not an available icon type.`);
            }
            return true;
        },
    },
};

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = "@-webkit-keyframes vue-feather--spin{0%{transform:rotate(0)}to{transform:rotate(1turn)}}@keyframes vue-feather--spin{0%{transform:rotate(0)}to{transform:rotate(1turn)}}.vue-feather{display:inline-block;overflow:hidden}.vue-feather--spin{-webkit-animation:vue-feather--spin 2s linear infinite;animation:vue-feather--spin 2s linear infinite}.vue-feather--pulse{-webkit-animation:vue-feather--spin 2s steps(8) infinite;animation:vue-feather--spin 2s steps(8) infinite}.vue-feather--slow{-webkit-animation-duration:3s;animation-duration:3s}.vue-feather--fast{-webkit-animation-duration:1s;animation-duration:1s}.vue-feather__content{display:block;height:inherit;width:inherit}";
styleInject(css_248z);

export default VueFeather;
